@@ -57,15 +57,13 @@
 
 #ifdef XFREE86_V4
 
-#ifndef XFree86LOADER
 #include <unistd.h>
 #include <errno.h>
-#endif
+#include <string.h>
 
 #include "misc.h"
 #include "xf86.h"
 #if !defined(DGUX)
-#include "xf86_ansic.h"
 #endif
 #include "xf86_OSproc.h"
 #include "xf86Xinput.h"
@@ -1825,7 +1823,7 @@ static XF86ModuleVersionInfo version_rec = {
   MODINFOSTRING1,
   MODINFOSTRING2,
   XORG_VERSION_CURRENT,
-  1, 0, 0,
+  1, 1, 0,
   ABI_CLASS_XINPUT,
   ABI_XINPUT_VERSION,
   MOD_CLASS_XINPUT,
